@@ -48,12 +48,12 @@ public:
 	virtual ~KGpgSignKey();
 
 protected:
-	virtual bool nextLine(const QString &line) Q_DECL_OVERRIDE;
-	virtual ts_boolanswer boolQuestion(const QString &line) Q_DECL_OVERRIDE;
-	virtual bool passphraseReceived() Q_DECL_OVERRIDE;
+	bool nextLine(const QString &line) Q_DECL_OVERRIDE;
+	ts_boolanswer boolQuestion(const QString &line) Q_DECL_OVERRIDE;
+	bool passphraseReceived() Q_DECL_OVERRIDE;
 
-	virtual KGpgTransaction *asTransaction() Q_DECL_OVERRIDE;
-	virtual void replaceCmd(const QString &cmd) Q_DECL_OVERRIDE;
+	KGpgTransaction *asTransaction() Q_DECL_OVERRIDE;
+	void replaceCmd(const QString &cmd) Q_DECL_OVERRIDE;
 };
 
 #endif // KGPGSIGNKEY_H
